@@ -27,6 +27,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, Dict, Generator, List, Optional, Tuple, Type, Union
 
 from deker_tools.data import convert_size_to_human
+from deker_tools.log import set_logger
 from deker_tools.path import is_path_valid
 from psutil import swap_memory, virtual_memory
 from tqdm import tqdm
@@ -42,7 +43,7 @@ from deker.errors import (
 )
 from deker.integrity import IntegrityChecker
 from deker.locks import META_DIVIDER
-from deker.log import SelfLoggerMixin, set_logging_level
+from deker.log import SelfLoggerMixin, format_string, set_logging_level
 from deker.schemas import ArraySchema, VArraySchema
 from deker.tools import convert_human_memory_to_bytes
 from deker.types import ArrayLockMeta, CollectionLockMeta, LocksExtensions, LocksTypes, StorageSize
@@ -142,20 +143,20 @@ class Client(SelfLoggerMixin):
                 "No installed adapters are found: run `pip install deker_local_adapters`"
             )
 
-        if self.__uri.scheme not in self.__plugins:
+        if self.__uri.scheme not in self.__plugins:  # type: ignore[attr-defined]
             raise DekerClientError(
-                f"Invalid uri: {self.__uri.scheme} is not supported; {self.__uri}"
+                f"Invalid uri: {self.__uri.scheme} is not supported; {self.__uri}"  # type: ignore[attr-defined]
             )
 
         if self.is_closed:
             self.__is_closed = False
 
             try:
-                factory = self.__plugins[self.__uri.scheme]
+                factory = self.__plugins[self.__uri.scheme]  # type: ignore[attr-defined]
             except AttributeError:
                 raise DekerClientError(
                     f"Invalid source: installed package does not provide AdaptersFactory "
-                    f"for managing uri scheme {self.__uri.scheme}"
+                    f"for managing uri scheme {self.__uri.scheme}"  # type: ignore[attr-defined]
                 )
 
             self.__ctx = CTX(
@@ -212,18 +213,23 @@ class Client(SelfLoggerMixin):
         :param kwargs: a wildcard, reserved for any extra parameters
         """
         try:
+            set_logger(format_string)
             set_logging_level(loglevel.upper())
             self.__get_plugins()
-            mem_limit = convert_human_memory_to_bytes(memory_limit)
+            total_available_mem = virtual_memory().total + swap_memory().total
+            memory_limit = convert_human_memory_to_bytes(memory_limit)
+            if memory_limit >= total_available_mem or memory_limit <= 0:
+                mem_limit = total_available_mem
+            else:
+                mem_limit = memory_limit
+
             self.__config = DekerConfig(  # type: ignore[call-arg]
                 uri=uri,
                 workers=workers if workers is not None else cpu_count() + 4,
                 write_lock_timeout=write_lock_timeout,
                 write_lock_check_interval=write_lock_check_interval,
                 loglevel=loglevel.upper(),
-                memory_limit=(
-                    virtual_memory().total + swap_memory().total if mem_limit <= 0 else mem_limit
-                ),
+                memory_limit=mem_limit,
             )
             self.__uri: Uri = Uri.create(self.__config.uri)
             self.__is_closed: bool = True
@@ -267,7 +273,10 @@ class Client(SelfLoggerMixin):
     @property
     def root_path(self) -> Path:
         """Get root path to the current storage."""
-        return Path(self.__adapter.uri.path) / self.__config.collections_directory
+        return (
+            Path(self.__adapter.uri.path)  # type: ignore[attr-defined]
+            / self.__config.collections_directory
+        )
 
     @property
     def is_closed(self) -> bool:
@@ -400,8 +409,10 @@ class Client(SelfLoggerMixin):
             self.logger.info(f"Collection {name} not found")
             return None
 
-    def collection_from_dict(self, collection_data: dict) -> Collection:
-        """Create a new ``Collection`` in the database from collection metadata dictionary.
+    def _validate_collection(self, collection_data: dict) -> Collection:
+        """Validate ``Collection`` object and return it without creation.
+
+        Not recommended to use except for validation.
 
         :param collection_data: Dictionary with collection metadata
         """
@@ -432,9 +443,16 @@ class Client(SelfLoggerMixin):
 
                     elif k not in collection_data[key]:
                         collection_data[key][k] = default_fields[key][k]
-        collection = self.__adapter.create_collection_from_meta(  # type: ignore[return-value]
+        return self.__adapter.create_collection_from_meta(  # type: ignore[return-value]
             collection_data, self.__factory
         )
+
+    def collection_from_dict(self, collection_data: dict) -> Collection:
+        """Create a new ``Collection`` in the database from collection metadata dictionary.
+
+        :param collection_data: Dictionary with collection metadata
+        """
+        collection = self._validate_collection(collection_data)
         self.__adapter.create(collection)
         self.logger.debug(f"Collection {collection.name} created from dict")
         return collection  # type: ignore[return-value]
